'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _ErrorHandler = require('../utils/ErrorHandler');

var timeouts = function timeouts(type, ms) {
    /*!
     * parameter check
     */
    if (typeof type !== 'string' || typeof ms !== 'number') {
        throw new _ErrorHandler.ProtocolError('number or type of arguments don\'t agree with timeouts protocol command');
    }

    return this.requestHandler.create('/session/:sessionId/timeouts', {
        type: type,
        ms: ms
    });
}; /**
    * Configure the amount of time that a particular type of operation can execute
    * for before they are aborted and a |Timeout| error is returned to the client.
    *
    * @param {String} type The type of operation to set the timeout for. Valid values are:<br>- **script** Determines when to interrupt a script that is being [evaluated](https://www.w3.org/TR/webdriver/#executing-script).<br>- **implicit** Gives the timeout of when to abort [locating an element](https://www.w3.org/TR/webdriver/#element-retrieval).<br>- **pageLoad** Provides the timeout limit used to interrupt [navigation](https://html.spec.whatwg.org/#navigate) of the [browsing context](https://html.spec.whatwg.org/#browsing-context). <br />The `pageLoad` keyword is a part of the official WebDriver [specification](https://www.w3.org/TR/webdriver/#set-timeouts), but might not be [supported](https://github.com/seleniumhq/selenium-google-code-issue-archive/issues/687) for your browser (the previous name is `page load`).
    * @param {Number} ms The amount of time, in milliseconds, that time-limited commands are permitted to run.
    *
    * @see https://www.w3.org/TR/webdriver/#dfn-get-timeouts
    * @type protocol
    *
    */

exports.default = timeouts;
module.exports = exports['default'];